@@ -146,18 +146,18 @@ def update_or_create(
         .first()
     )
 
-    if instance:
-        # Update
-        for k, v in obj.items():
-            instance.__setattr__(k, v)
-        session.commit()
-        return instance, False
-
     # Validate
     data, errors = schema().load(obj)
     if errors:
         raise ValidationError(errors)
 
+    if instance:
+        # Update
+        for k, v in data.items():
+            instance.__setattr__(k, v)
+        session.commit()
+        return instance, False
+
     # Create
     instance = model(**data)
     session.add(instance)
