@@ -6,6 +6,7 @@ from sqlalchemy import (
     String,
     DateTime,
     Text,
+    ForeignKey,
 )
 
 from ...database import Base
@@ -18,6 +19,11 @@ class DrugIndicationModel(Base):
     set_id = Column(String(128), nullable=False, index=True)
     lowercase_indication = Column(String(128), nullable=True)
     indication = Column(Text, nullable=True)
+    label_file_id = Column(
+        Integer,
+        ForeignKey('files.id'),
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
