@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     String,
     DateTime,
+    Boolean,
 )
 
 from ...database import Base
@@ -18,6 +19,7 @@ class DrugIndicationUMLSModel(Base):
     cui = Column(String(50), nullable=False)
     preferred_name = Column(String(128), nullable=True)
     score = Column(Integer, nullable=True)
+    final_mapping = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
