@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     UniqueConstraint,
+    Boolean,
 )
 
 from ...database import Base
@@ -25,6 +26,7 @@ class InterventionPharmActionModel(Base):
         ForeignKey('pharm_actions.id'),
         nullable=False,
     )
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
