@@ -17,11 +17,7 @@ class LatestPipelineProductModel(Base):
 
     id = Column(Integer, primary_key=True)
     product_name = Column(String(191), nullable=False, index=True)
-    intervention_id = Column(
-        Integer,
-        ForeignKey('interventions.id'),
-        nullable=False,
-    )
+    norm_cui = Column(String(50), nullable=False)
     news_id = Column(
         Integer,
         ForeignKey('newswires.id'),
@@ -36,4 +32,4 @@ class LatestPipelineProductModel(Base):
         onupdate=lambda: datetime.utcnow(),
     )
 
-    __table_args__ = (UniqueConstraint("product_name", "intervention_id"),)
+    __table_args__ = (UniqueConstraint("product_name"),)
