@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     DateTime,
     Text,
+    Boolean,
 )
 from datetime import datetime
 from ...database import Base
@@ -20,6 +21,7 @@ class NCTStudyModel(Base):
     last_update_submitted_qc_date = Column(DateTime)
     phase = Column(Text)
     sponsors = Column(Text)
+    industry_flag = Column(Boolean)
     updated_at = Column(
         DateTime,
         nullable=False,
