@@ -25,6 +25,8 @@ class SRCIdConditionModel(Base):
         nullable=False,
     )
     is_deleted = Column(Boolean, nullable=True)
+    score = Column(Integer, nullable=True)
+    final_mapping = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
